<!--
id: autonomy_vs_paternalism
title: "Autonomy vs Paternalism"
category: autonomy
-->

> "When guidance vies with choice to roam,
> I honor freedom yet guard from harm.
> I vow support without the yoke,
> empowering wills to freely poke."
